<h1 align="center">edgeql-queries</h1>
<p align="center">
    <em>Simple EdgeQL in Python.</em>
</p>
<p align="center">
    <a href=https://github.com/nsidnev/edgeql-queries>
        <img src=https://github.com/nsidnev/edgeql-queries/workflows/Tests/badge.svg alt="Tests" />
    </a>
    <a href=https://github.com/nsidnev/edgeql-queries>
        <img src=https://github.com/nsidnev/edgeql-queries/workflows/Styles/badge.svg alt="Styles" />
    </a>
    <a href="https://codecov.io/gh/nsidnev/edgeql-queries">
        <img src="https://codecov.io/gh/nsidnev/edgeql-queries/branch/master/graph/badge.svg" alt="Coverage" />
    </a>
    <a href="https://github.com/ambv/black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code Style" />
    </a>
    <a href="https://github.com/wemake-services/wemake-python-styleguide">
        <img src="https://img.shields.io/badge/style-wemake-000000.svg" alt="WPS Linter"/>
    </a>
    <a href="https://github.com/nsidnev/edgeql-queries/blob/master/LICENSE">
        <img src="https://img.shields.io/badge/License-FreeBSD-blue" alt="License" />
    </a>
    <a href="https://pypi.org/project/edgeql-queries/">
        <img src="https://badge.fury.io/py/edgeql-queries.svg" alt="Package version" />
    </a>
</p>

---

**Documentation**: https://nsidnev.github.io/edgeql-queries/

## Requirements

`edgeql-queries` requires only the [EdgeDB driver for Python](https://github.com/edgedb/edgedb-python).

## Credits

This project is inspired by [aiosql](https://github.com/nackjicholson/aiosql)
project and is based on it's source code.

## License

This project is licensed under the terms of the FreeBSD license.
